@@ -8,10 +8,10 @@
 # || License: GNU GPL version 2 or any later version.                       ||
 # ||                                                                        ||
 # +==========================================================================+
-# ID:       $Id: Task.pm 4037 2009-04-23 17:33:19Z christian-guest $
-# Revision: $Revision: 4037 $
+# ID:       $Id: Task.pm 4249 2009-10-11 13:22:24Z christian-guest $
+# Revision: $Revision: 4249 $
 # Head URL: $HeadURL$
-# Date:     $Date: 2009-04-23 19:33:19 +0200 (Thu, 23 Apr 2009) $
+# Date:     $Date: 2009-10-11 15:22:24 +0200 (Sun, 11 Oct 2009) $
 # Source:   $Source$
 
 package CipUX::Task;
@@ -37,7 +37,7 @@ use Term::ReadKey;
 use base qw(CipUX);
 {                                          # BEGIN CLASS
 
-    use version; our $VERSION = qv('3.4.0.2');
+    use version; our $VERSION = qv('3.4.0.6');
     use re 'taint';    # Keep data captured by parens tainted
     delete @ENV{qw(PATH IFS CDPATH ENV BASH_ENV)};    # Make %ENV safe
 
@@ -70,12 +70,18 @@ use base qw(CipUX);
             ? $self->l( $arg_r->{pref} )
             : $EMPTY_STRING;
 
+        my $cache_dir
+            = exists $arg_r->{cache_dir}
+            ? $self->l( $arg_r->{cache_dir} )
+            : $EMPTY_STRING;
+
         # +------------------------------------------------------------------+
         # | prepare
 
         # +------------------------------------------------------------------+
         # | main
-        my $cfg_hr = $self->cfg( { 'sub' => 'task', pref => $pref } );
+        my $cfg_hr = $self->cfg(
+            { 'sub' => 'task', pref => $pref, cache_dir => $cache_dir } );
 
         $task_api_cfg{$obj_id} = $cfg_hr->{task_api};
 
@@ -236,6 +242,7 @@ use base qw(CipUX);
                     status    => 'OK',
                     type      => 'href',
                     taskres_r => $return_hr,
+                    ltarget   => 'NULL',
                 };
 
                 # if there is a doggy in cipux-task.conf we let the dog run
@@ -300,10 +307,12 @@ use base qw(CipUX);
 
                 }
 
+                # destroy_object_action return
                 my $status_hr = {
                     status    => 'OK',
                     type      => 'href',
                     taskres_r => $return_hr,
+                    ltarget   => 'NULL',
                 };
 
                 # if there is a doggy in cipux-task.conf we let the dog run
@@ -369,10 +378,18 @@ use base qw(CipUX);
                     }
                 } ## end if ( $mode eq 'shell' )
 
+                my $ltarget
+                    = ( exists $task_api{$task}{ltarget} )
+                    ? $task_api{$task}{ltarget}
+                    : 'NULL';
+                $logger->debug("ltarget [$ltarget]");
+
+                # list_object_action return
                 my $status_hr = {
                     status    => 'OK',
                     type      => 'href',
                     taskres_r => $return_hr,
+                    ltarget   => $ltarget,
                 };
 
                 # if there is a doggy in cipux-task.conf we let the dog run
@@ -524,7 +541,9 @@ use base qw(CipUX);
                     # cycle over cipux_objects of targets
                     foreach my $o ( keys %{ $task_api{$task}{target} } ) {
                         foreach my $t (
-                            sort keys %{ $task_api{$task}{target}->{$o} } )
+                            sort
+                            keys %{ $task_api{$task}{target}->{$o} }
+                            )
                         {
                             $logger->debug(
                                 "add target [$t] for cipux object [$o]");
@@ -617,10 +636,18 @@ use base qw(CipUX);
 
                 } ## end if ( $mode eq 'shell' )
 
+                my $ltarget
+                    = ( exists $task_api{$task}{ltarget} )
+                    ? $task_api{$task}{ltarget}
+                    : 'NULL';
+                $logger->debug("ltarget [$ltarget]");
+
+                # list_object_attribute_action
                 my $status_hr = {
                     status    => 'OK',
                     type      => 'href',
                     taskres_r => $return_hr,
+                    ltarget   => $ltarget,
                 };
 
                 # if there is a doggy in cipux-task.conf we let the dog run
@@ -681,7 +708,7 @@ use base qw(CipUX);
                     if (
                             $mode eq 'shell'
                         and $task =~ m{^cipux_task_change_}smx
-                        and $task =~ m{_password_on_command_line$}smx
+                        and $task =~ m{_password_interactive$}smx
 
                         )
                     {
@@ -836,10 +863,13 @@ use base qw(CipUX);
              #else {
              #    $logger->debug('did return nothing!');
              #}
+
+                # change_object_attribute_action return
                 my $status_hr = {
                     status    => 'OK',
                     type      => 'href',
                     taskres_r => $return_hr,
+                    ltarget   => 'NULL',
                 };
 
                 # if there is a doggy in cipux-task.conf we let the dog run
@@ -922,10 +952,13 @@ use base qw(CipUX);
                         : $attr_hr->{summand2};
 
                     my $sum = $s1 + $s2;
+
+                    # no LDAP task return
                     return {
                         status    => 'OK',
                         type      => 'aref',
                         taskres_r => [$sum],
+                        ltarget   => 'NULL',
                     };
                 } ## end if ( $task eq 'cipux_task_sum')
             } ## end else [ if ( $mode eq 'shell' )
@@ -1017,6 +1050,8 @@ use base qw(CipUX);
                 '... no, CipUX::Dog not installed. Will not run the dog.');
         }
 
+        return;
+
     }
 
     sub snd_task {
@@ -1111,7 +1146,7 @@ CipUX::Task - Task layer class for CipUX
 
 =head1 VERSION
 
-version 3.4.0.2
+version 3.4.0.6
 
 
 =head1 SYNOPSIS
@@ -1219,4 +1254,3 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 02111-1307 USA
 
 =cut
-
